@@ -28,34 +28,38 @@ import time
 from paramiko.py3compat import PY2, b
 
 
-class PipeTimeout (IOError):
+class PipeTimeout(IOError):
     """
     Indicates that a timeout was reached on a read from a `.BufferedPipe`.
     """
+
     pass
 
 
-class BufferedPipe (object):
+class BufferedPipe(object):
     """
     A buffer that obeys normal read (with timeout) & close semantics for a
     file or socket, but is fed data from another thread.  This is used by
     `.Channel`.
     """
-    
+
     def __init__(self):
         self._lock = threading.Lock()
         self._cv = threading.Condition(self._lock)
         self._event = None
-        self._buffer = array.array('B')
+        self._buffer = array.array("B")
         self._closed = False
 
     if PY2:
+
         def _buffer_frombytes(self, data):
             self._buffer.fromstring(data)
 
         def _buffer_tobytes(self, limit=None):
             return self._buffer[:limit].tostring()
+
     else:
+
         def _buffer_frombytes(self, data):
             self._buffer.frombytes(data)
 
@@ -67,7 +71,7 @@ class BufferedPipe (object):
         Set an event on this buffer.  When data is ready to be read (or the
         buffer has been closed), the event will be set.  When no data is
         ready, the event will be cleared.
-        
+
         :param threading.Event event: the event to set/clear
         """
         self._lock.acquire()
@@ -84,13 +88,13 @@ class BufferedPipe (object):
                 event.clear()
         finally:
             self._lock.release()
-        
+
     def feed(self, data):
         """
         Feed new data into this pipe.  This method is assumed to be called
         from a separate thread, so synchronization is done.
-        
-        :param data: the data to add, as a `str` or `bytes`
+
+        :param data: the data to add, as a ``str`` or ``bytes``
         """
         self._lock.acquire()
         try:
@@ -106,7 +110,7 @@ class BufferedPipe (object):
         Returns true if data is buffered and ready to be read from this
         feeder.  A ``False`` result does not mean that the feeder has closed;
         it means you may need to wait before more data arrives.
-        
+
         :return:
             ``True`` if a `read` call would immediately return at least one
             byte; ``False`` otherwise.
@@ -134,11 +138,11 @@ class BufferedPipe (object):
         :param int nbytes: maximum number of bytes to read
         :param float timeout:
             maximum seconds to wait (or ``None``, the default, to wait forever)
-        :return: the read data, as a `bytes`
-        
-        :raises PipeTimeout:
-            if a timeout was specified and no data was ready before that
-            timeout
+        :return: the read data, as a ``str`` or ``bytes``
+
+        :raises:
+            `.PipeTimeout` -- if a timeout was specified and no data was ready
+            before that timeout
         """
         out = bytes()
         self._lock.acquire()
@@ -172,11 +176,11 @@ class BufferedPipe (object):
             self._lock.release()
 
         return out
-    
+
     def empty(self):
         """
         Clear out the buffer and return all data that was in it.
-        
+
         :return:
             any data that was in the buffer prior to clearing it out, as a
             `str`
@@ -190,7 +194,7 @@ class BufferedPipe (object):
             return out
         finally:
             self._lock.release()
-    
+
     def close(self):
         """
         Close this pipe object.  Future calls to `read` after the buffer
@@ -208,7 +212,7 @@ class BufferedPipe (object):
     def __len__(self):
         """
         Return the number of bytes buffered.
-        
+
         :return: number (`int`) of bytes buffered
         """
         self._lock.acquire()
